import { Kysely } from "kysely";
import { Exporter } from "poe-dat-export";
import Database from "better-sqlite3";
import Debug from "debug";
import { Language, Schema } from "./models";
export declare class PoEDB extends Kysely<Schema.DB> {
    protected readonly _debug: Debug.Debugger;
    protected readonly _exporter: Exporter.DatExporter;
    protected readonly _sqliteDb: Database.Database;
    protected readonly _dbPath: string;
    protected readonly _cacheDir: string | undefined;
    protected readonly _cacheDuration: number | undefined;
    /**
     * @param dbPath The location of the sqlite db. If the path is relative,
     * it will be resolved using the cwd
     *
     * @param cacheDir The directory used for caching. If the path is relative,
     * it will be resolved using the cwd. If not specified, the default will be used
     */
    constructor(dbPath?: string, cacheDir?: string, cacheDuration?: number);
    /**
     * The path to the sqlite database
     */
    get DbPath(): string;
    /**
     * The absolute path to the cache directory
     */
    get CacheDir(): string | undefined;
    /**
     * The time in ms items stay in cache
     */
    get CacheDuration(): number | undefined;
    /**
     * Tries to load the data of the given table into the database
     *
     * @remarks Some tables cannot be exported because the decompression process fails.
     * Unfortunately, there's currently no fix for this.
     *
     * @remarks Booleans are stored as text: 'true' & 'false'
     *
     * @remarks Arrays and objects are stored in JSON format
     *
     *
     * @param table The name of the table
     * @param languages The languages in which the table will be loaded
     * @param ignoreDuplicateError If set, insertion of existing rows does not throw an error
     */
    tryLoadTable(table: keyof Schema.DB, languages?: Array<Language>, ignoreDuplicateError?: boolean): Promise<void>;
    protected _insertData(data: Exporter.ExportResult[], table: keyof Schema.DB, ignoreDuplicateError: boolean): Promise<void>;
    /**
     * Preprocesses the data before insertion.
     * This is especially necessary for non-sqlite datatypes, e.g. boolean, arrays & objects
     *
     * @remarks Entries in `data` are changed
     */
    protected _preprocessData(data: Exporter.ExportResult[], language: Language): void;
}
